@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2011, 2019, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
@@ -22,23 +22,38 @@
  */
 
 #include "base/sqlstring.h"
+#include "base/symbol-info.h"
 
 using namespace base;
 
 const sqlstring sqlstring::null(sqlstring("NULL", 0));
 
-sqlstring::sqlstring(const char *format_string, const sqlstringformat format)
+//----------------------------------------------------------------------------------------------------------------------
+
+sqlstring::sqlstring(const std::string &format_string, const sqlstringformat format)
   : _format_string_left(format_string), _format(format) {
   append(consume_until_next_escape());
 }
 
+//----------------------------------------------------------------------------------------------------------------------
+
+sqlstring::sqlstring(const char format_string[], const sqlstringformat format)
+  : sqlstring(std::string(format_string), format) {
+}
+
+//----------------------------------------------------------------------------------------------------------------------
+
 sqlstring::sqlstring(const sqlstring &copy)
   : _formatted(copy._formatted), _format_string_left(copy._format_string_left), _format(copy._format) {
 }
 
+//----------------------------------------------------------------------------------------------------------------------
+
 sqlstring::sqlstring() : _format(0) {
 }
 
+//----------------------------------------------------------------------------------------------------------------------
+
 std::string sqlstring::consume_until_next_escape() {
   std::string::size_type e = _format_string_left.length(), p = 0;
   while (p < e) {
@@ -58,6 +73,8 @@ std::string sqlstring::consume_until_next_escape() {
   return "";
 }
 
+//----------------------------------------------------------------------------------------------------------------------
+
 int sqlstring::next_escape() {
   if (_format_string_left.empty())
     throw std::invalid_argument("Error formatting SQL query: more arguments than escapes");
@@ -66,21 +83,29 @@ int sqlstring::next_escape() {
   return c;
 }
 
+//----------------------------------------------------------------------------------------------------------------------
+
 sqlstring &sqlstring::append(const std::string &s) {
   _formatted.append(s);
   return *this;
 }
 
+//----------------------------------------------------------------------------------------------------------------------
+
 sqlstring::operator std::string() const {
   return _formatted + _format_string_left;
 }
 
+//----------------------------------------------------------------------------------------------------------------------
+
 bool sqlstring::done() const {
   if (_format_string_left.empty())
     return true;
   return _format_string_left[0] != '!' && _format_string_left[0] != '?';
 }
 
+//----------------------------------------------------------------------------------------------------------------------
+
 sqlstring &sqlstring::operator<<(const double v) {
   int esc = next_escape();
   if (esc != '?')
@@ -92,17 +117,21 @@ sqlstring &sqlstring::operator<<(const double v) {
   return *this;
 }
 
+//----------------------------------------------------------------------------------------------------------------------
+
 sqlstring &sqlstring::operator<<(const sqlstringformat format) {
   _format = format;
   return *this;
 }
 
+//----------------------------------------------------------------------------------------------------------------------
+
 sqlstring &sqlstring::operator<<(const std::string &v) {
   int esc = next_escape();
   if (esc == '!') {
     std::string escaped = escape_backticks(v);
     if ((_format._flags & QuoteOnlyIfNeeded) != 0)
-      append(base::quote_identifier_if_needed(escaped, '`'));
+      append(base::quoteIdentifierIfNeeded(escaped, '`', MySQLVersion::MySQL80)); // XXX: make this configurable.
     else
       append(base::quote_identifier(escaped, '`'));
   } else if (esc == '?') {
@@ -118,6 +147,8 @@ sqlstring &sqlstring::operator<<(const std::string &v) {
   return *this;
 }
 
+//----------------------------------------------------------------------------------------------------------------------
+
 sqlstring &sqlstring::operator<<(const sqlstring &v) {
   next_escape();
 
@@ -153,3 +184,5 @@ sqlstring &sqlstring::operator<<(const char *v) {
 
   return *this;
 }
+
+//----------------------------------------------------------------------------------------------------------------------
