@@ -406,6 +406,9 @@ void CodeEditor::updateColors() {
   // Other settings.
   color = Color::getSystemColor(base::SelectedTextBackgroundColor);
   _code_editor_impl->send_editor(this, SCI_SETSELBACK, 1, color.toBGR());
+#ifndef __APPLE__
+  _code_editor_impl->send_editor(this, SCI_SETSELALPHA, 64, 0);
+#endif
 
   if (darkMode) {
     _code_editor_impl->send_editor(this, SCI_SETCARETLINEBACK, 0xFFFFFF, 0);
@@ -653,20 +656,24 @@ void CodeEditor::replace_selected_text(const std::string& text) {
 //----------------------------------------------------------------------------------------------------------------------
 
 const std::string CodeEditor::get_text(bool selection_only) {
-  char* text;
+  char* text = nullptr;
   sptr_t length;
   if (selection_only) {
     length = _code_editor_impl->send_editor(this, SCI_GETSELTEXT, 0, 0);
-    text = (char*)malloc(length);
-    if (text != NULL) // Can be null if not memory is available.
+    if (length > 0) {
+      text = (char*)malloc(length);
+    }
+    if (text != nullptr) // Can be null if not memory is available.
       _code_editor_impl->send_editor(this, SCI_GETSELTEXT, length, (sptr_t)text);
   } else {
     length = _code_editor_impl->send_editor(this, SCI_GETTEXTLENGTH, 0, 0) + 1;
-    text = (char*)malloc(length);
-    if (text != NULL)
+    if (length > 0) {
+      text = (char*)malloc(length);
+    }
+    if (text != nullptr)
       _code_editor_impl->send_editor(this, SCI_GETTEXT, length, (sptr_t)text);
   }
-  if (text != NULL) {
+  if (text != nullptr) {
     std::string result(text, length - 1);
     free(text);
 
@@ -801,7 +808,7 @@ void CodeEditor::handleMarkerDeletion(size_t position, size_t length) {
 /**
  * Called after an edit action took place. We have to record markers that got moved by that action.
  */
-void CodeEditor::handleMarkerMove(size_t position, int linesAdded) {
+void CodeEditor::handleMarkerMove(Sci_Position position, Sci_Position linesAdded) {
   if (linesAdded == 0)
     return;
 
@@ -818,7 +825,7 @@ void CodeEditor::handleMarkerMove(size_t position, int linesAdded) {
   }
 
   // Ignore the first line if it has been edited after the line start.
-  if (position > static_cast<size_t>(_code_editor_impl->send_editor(this, SCI_POSITIONFROMLINE, currentLine, 0)))
+  if (position > static_cast<Sci_Position>(_code_editor_impl->send_editor(this, SCI_POSITIONFROMLINE, currentLine, 0)))
     ++currentLine;
 
   currentLine = _code_editor_impl->send_editor(this, SCI_MARKERNEXT, currentLine, LineMarkupAll);
@@ -837,7 +844,7 @@ void CodeEditor::handleMarkerMove(size_t position, int linesAdded) {
 //----------------------------------------------------------------------------------------------------------------------
 
 char32_t CodeEditor::getCharAt(size_t position) {
-  return _code_editor_impl->send_editor(this, SCI_GETCHARAT, position, 0);
+  return static_cast<char32_t>(_code_editor_impl->send_editor(this, SCI_GETCHARAT, position, 0));
 }
 
 //----------------------------------------------------------------------------------------------------------------------
@@ -881,45 +888,42 @@ bool CodeEditor::ensureImage(std::string const& name) {
   if (registeredImages.find(name) != registeredImages.end())
     return true;
 
-  std::string path = App::get()->get_resource_path(name);
-  if (base::file_exists(path) && base::hasSuffix(path, ".png")) {
-    cairo_surface_t* image = Utilities::load_icon(path);
-    if (image == NULL)
-      return false;
+  cairo_surface_t* image = Utilities::load_icon(name);
+  if (image == nullptr)
+    return false;
 
-    if (cairo_surface_status(image) != CAIRO_STATUS_SUCCESS) {
-      cairo_surface_destroy(image);
-      return false;
-    }
-
-    int width = cairo_image_surface_get_width(image);
-    int height = cairo_image_surface_get_height(image);
-
-    unsigned char* data = cairo_image_surface_get_data(image);
-
-    // We not only need to keep the data around for the lifetime of the editor we also have
-    // to swap blue and red.
-    unsigned char *target = reinterpret_cast<unsigned char *>(malloc(4 * width * height));
-    if (target != nullptr) {
-      ImageRecord entry = {
-        Utilities::is_hidpi_icon(image),
-        cairo_image_surface_get_width(image),
-        cairo_image_surface_get_height(image),
-        target
-      };
-      registeredImages[name] = entry;
-      int j = 0;
-      while (j < 4 * width * height) {
-        target[j] = data[j + 2];
-        target[j + 1] = data[j + 1];
-        target[j + 2] = data[j];
-        target[j + 3] = data[j + 3];
-        j += 4;
-      }
-    }
+  if (cairo_surface_status(image) != CAIRO_STATUS_SUCCESS) {
     cairo_surface_destroy(image);
+    return false;
   }
 
+  int width = cairo_image_surface_get_width(image);
+  int height = cairo_image_surface_get_height(image);
+
+  unsigned char* data = cairo_image_surface_get_data(image);
+
+  // We not only need to keep the data around for the lifetime of the editor we also have
+  // to swap blue and red.
+  unsigned char *target = reinterpret_cast<unsigned char *>(malloc(4 * width * height));
+  if (target != nullptr) {
+    ImageRecord entry = {
+      Utilities::is_hidpi_icon(image),
+      cairo_image_surface_get_width(image),
+      cairo_image_surface_get_height(image),
+      target
+    };
+    registeredImages[name] = entry;
+    int j = 0;
+    while (j < 4 * width * height) {
+      target[j] = data[j + 2];
+      target[j + 1] = data[j + 1];
+      target[j + 2] = data[j];
+      target[j + 3] = data[j + 3];
+      j += 4;
+    }
+  }
+  cairo_surface_destroy(image);
+
   return true;
 }
 
@@ -929,50 +933,51 @@ void CodeEditor::loadConfiguration(SyntaxHighlighterLanguage language) {
   CodeEditorConfig config(language);
 
   // Keywords.
-  std::map<std::string, std::string> keywords = config.get_keywords();
-
-  // Key word list sets are from currently active lexer, so that must be set before calling here.
-  sptr_t length = _code_editor_impl->send_editor(this, SCI_DESCRIBEKEYWORDSETS, 0, 0);
-  if (length > 0) {
-    char* keyword_sets = (char*)malloc(length + 1);
-    _code_editor_impl->send_editor(this, SCI_DESCRIBEKEYWORDSETS, 0, (sptr_t)keyword_sets);
-    std::vector<std::string> keyword_list_names = base::split(keyword_sets, "\n");
-    free(keyword_sets);
-
-    // Note: this part is in the process of being converted to a different approach (parsers know all keywords
-    //       so they can actually provide them, instead of a manually managed config file).
-    for (auto iterator : keywords) {
-      std::string list_name = iterator.first;
-      int list_index = base::index_of(keyword_list_names, list_name);
-      if (list_index > -1)
-        _code_editor_impl->send_editor(this, SCI_SETKEYWORDS, list_index, (sptr_t)iterator.second.c_str());
-    }
-
-    // First part delivered by a parser are function names in MySQL.
-    size_t version = 0;
+  if (language == LanguageMySQL56 || language == LanguageMySQL57 || language == LanguageMySQL80) {
+    MySQLVersion version;
     switch (language) {
       case LanguageMySQL56:
-        version = 506;
+        version = MySQLVersion::MySQL56;
         break;
       case LanguageMySQL57:
-        version = 507;
+        version = MySQLVersion::MySQL57;
         break;
-      case LanguageMySQL80:
-        version = 800;
-        break;
-
       default:
+        version = MySQLVersion::MySQL80;
         break;
     }
 
-    if (version > 0) {
-      parsers::SymbolTable* functions = parsers::functionSymbolsForVersion(version);
-      std::set<std::string> functionNames = functions->getAllSymbolNames();
-      std::string functionList;
-      for (auto const& name : functionNames)
-        functionList += name + " ";
+    auto &functions = MySQLSymbolInfo::systemFunctionsForVersion(version);
+    std::string list;
+    for (auto const& name : functions)
+      list += base::tolower(name) + " "; // Keyword matching in Scintilla uses lower case compare.
 
-      _code_editor_impl->send_editor(this, SCI_SETKEYWORDS, 3, (sptr_t)functionList.c_str());
+    _code_editor_impl->send_editor(this, SCI_SETKEYWORDS, 3, (sptr_t)list.c_str());
+
+    auto &keywords = MySQLSymbolInfo::keywordsForVersion(version);
+    list = "";
+    for (auto const& name : keywords)
+      list += base::tolower(name) + " ";
+
+    _code_editor_impl->send_editor(this, SCI_SETKEYWORDS, 1, (sptr_t)list.c_str());
+
+  } else {
+    std::map<std::string, std::string> keywords = config.get_keywords();
+
+    // Key word list sets are from currently active lexer, so that must be set before calling here.
+    sptr_t length = _code_editor_impl->send_editor(this, SCI_DESCRIBEKEYWORDSETS, 0, 0);
+    if (length > 0) {
+      char* keyword_sets = (char*)malloc(length + 1);
+      _code_editor_impl->send_editor(this, SCI_DESCRIBEKEYWORDSETS, 0, (sptr_t)keyword_sets);
+      std::vector<std::string> keyword_list_names = base::split(keyword_sets, "\n");
+      free(keyword_sets);
+
+      for (auto iterator : keywords) {
+        std::string list_name = iterator.first;
+        int list_index = base::index_of(keyword_list_names, list_name);
+        if (list_index > -1)
+          _code_editor_impl->send_editor(this, SCI_SETKEYWORDS, list_index, reinterpret_cast<sptr_t>(iterator.second.c_str()));
+      }
     }
   }
 
