@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2021, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
@@ -34,8 +34,8 @@ using namespace base;
 static int dict_init(PyGRTDictObject *self, PyObject *args, PyObject *kwds) {
   PythonContext *ctx = PythonContext::get_and_check();
   if (ctx) {
-    const char *type = NULL, *class_name = NULL;
-    PyObject *valueptr = NULL;
+    const char *type = nullptr, *class_name = nullptr;
+    PyObject *valueptr = nullptr;
     static const char *kwdict[] = {"type", "classname", "__valueptr__", 0};
 
     if (!PyArg_ParseTupleAndKeywords(args, kwds, "|zzO", (char **)kwdict, &type, &class_name, &valueptr))
@@ -83,7 +83,7 @@ static int dict_init(PyGRTDictObject *self, PyObject *args, PyObject *kwds) {
 static void dict_dealloc(PyGRTDictObject *self) {
   delete self->dict;
 
-  self->ob_type->tp_free(self);
+  Py_TYPE(self)->tp_free(self);
 }
 
 static Py_ssize_t dict_length(PyGRTDictObject *self) {
@@ -91,12 +91,8 @@ static Py_ssize_t dict_length(PyGRTDictObject *self) {
 }
 
 static PyObject *dict_getattro(PyGRTDictObject *self, PyObject *attr_name) {
-  AutoPyObject tmp;
-  if (PyUnicode_Check(attr_name))
-    attr_name = tmp = PyUnicode_AsUTF8String(attr_name);
-
-  if (PyString_Check(attr_name)) {
-    const char *attrname = PyString_AsString(attr_name);
+  if (PyUnicode_Check(attr_name)) {
+    const char *attrname = PyUnicode_AsUTF8(attr_name);
 
     PyObject *object;
     if ((object = PyObject_GenericGetAttr((PyObject *)self, attr_name)))
@@ -107,19 +103,19 @@ static PyObject *dict_getattro(PyGRTDictObject *self, PyObject *attr_name) {
       PyObject *members = Py_BuildValue("[s]", "__contenttype__");
 
       for (grt::DictRef::const_iterator iter = self->dict->begin(); iter != self->dict->end(); ++iter) {
-        PyObject *tmp = PyString_FromString(iter->first.c_str());
+        PyObject *tmp = PyUnicode_FromString(iter->first.c_str());
         PyList_Append(members, tmp);
         Py_DECREF(tmp);
       }
       return members;
     } else if (strcmp(attrname, "__methods__") == 0) {
-      PyObject *methods = Py_BuildValue("[sssss]", "keys", "items", "values", "has_key", "update", "setdefault");
+      PyObject *methods = Py_BuildValue("[sssssss]", "keys", "items", "values", "has_key", "update", "get", "setdefault");
       return methods;
     } else {
       if (self->dict->has_key(attrname)) {
         PythonContext *ctx = PythonContext::get_and_check();
         if (!ctx)
-          return NULL;
+          return nullptr;
 
         return ctx->from_grt(self->dict->get(attrname));
       } else
@@ -127,52 +123,44 @@ static PyObject *dict_getattro(PyGRTDictObject *self, PyObject *attr_name) {
     }
   }
   PyErr_SetString(PyExc_KeyError, "grt.Dict key must be a string");
-  return NULL;
+  return nullptr;
 }
 
 static PyObject *dict_subscript(PyGRTDictObject *self, PyObject *key) {
-  AutoPyObject tmp;
-  if (PyUnicode_Check(key))
-    key = tmp = PyUnicode_AsUTF8String(key);
-
-  if (!PyString_Check(key)) {
+  if (!PyUnicode_Check(key)) {
     PyErr_SetString(PyExc_KeyError, "grt.Dict key must be a string");
-    return NULL;
+    return nullptr;
   }
-  const char *k = PyString_AsString(key);
+  const char *k = PyUnicode_AsUTF8(key);
   PythonContext *ctx = PythonContext::get_and_check();
   if (!ctx)
-    return NULL;
+    return nullptr;
 
   try {
     return ctx->from_grt(self->dict->get(k));
   } catch (grt::bad_item &exc) {
     PythonContext::set_python_error(exc);
-    return NULL;
+    return nullptr;
   } catch (std::exception &exc) {
     PythonContext::set_python_error(exc);
-    return NULL;
+    return nullptr;
   }
-  return NULL;
+  return nullptr;
 }
 
 static int dict_ass_subscript(PyGRTDictObject *self, PyObject *key, PyObject *value) {
-  AutoPyObject tmp;
-  if (PyUnicode_Check(key))
-    key = tmp = PyUnicode_AsUTF8String(key);
-
-  if (!PyString_Check(key)) {
+  if (!PyUnicode_Check(key)) {
     PyErr_SetString(PyExc_KeyError, "grt.Dict key must be a string");
     return -1;
   }
-  const char *k = PyString_AsString(key);
+  const char *k = PyUnicode_AsUTF8(key);
 
   PythonContext *ctx = PythonContext::get_and_check();
   if (!ctx)
     return -1;
 
   try {
-    if (value == NULL)
+    if (value == nullptr)
       self->dict->remove(k);
     else if (value == Py_None)
       self->dict->set(k, grt::ValueRef());
@@ -196,13 +184,13 @@ static int dict_ass_subscript(PyGRTDictObject *self, PyObject *key, PyObject *va
 static PyObject *dict_keys(PyGRTDictObject *self, PyObject *args) {
   if (args) {
     PyErr_SetString(PyExc_ValueError, "method takes no arguments");
-    return NULL;
+    return nullptr;
   }
   PyObject *list = PyList_New(self->dict->count());
 
   Py_ssize_t i = 0;
   for (grt::DictRef::const_iterator iter = self->dict->begin(); iter != self->dict->end(); ++iter)
-    PyList_SetItem(list, i++, PyString_FromString(iter->first.c_str()));
+    PyList_SetItem(list, i++, PyUnicode_FromString(iter->first.c_str()));
 
   return list;
 }
@@ -210,17 +198,17 @@ static PyObject *dict_keys(PyGRTDictObject *self, PyObject *args) {
 static PyObject *dict_items(PyGRTDictObject *self, PyObject *args) {
   if (args) {
     PyErr_SetString(PyExc_ValueError, "method takes no arguments");
-    return NULL;
+    return nullptr;
   }
   PythonContext *ctx = PythonContext::get_and_check();
   if (!ctx)
-    return NULL;
+    return nullptr;
   PyObject *list = PyList_New(self->dict->count());
 
   Py_ssize_t i = 0;
   for (grt::DictRef::const_iterator iter = self->dict->begin(); iter != self->dict->end(); ++iter) {
     PyObject *tuple = PyTuple_New(2);
-    PyTuple_SetItem(tuple, 0, PyString_FromString(iter->first.c_str()));
+    PyTuple_SetItem(tuple, 0, PyUnicode_FromString(iter->first.c_str()));
     PyTuple_SetItem(tuple, 1, ctx->from_grt(iter->second));
     PyList_SetItem(list, i++, tuple);
   }
@@ -230,11 +218,11 @@ static PyObject *dict_items(PyGRTDictObject *self, PyObject *args) {
 static PyObject *dict_values(PyGRTDictObject *self, PyObject *args) {
   if (args) {
     PyErr_SetString(PyExc_ValueError, "method takes no arguments");
-    return NULL;
+    return nullptr;
   }
   PythonContext *ctx = PythonContext::get_and_check();
   if (!ctx)
-    return NULL;
+    return nullptr;
   PyObject *list = PyList_New(self->dict->count());
 
   Py_ssize_t i = 0;
@@ -247,10 +235,10 @@ static PyObject *dict_values(PyGRTDictObject *self, PyObject *args) {
 static PyObject *dict_has_key(PyGRTDictObject *self, PyObject *arg) {
   if (!arg) {
     PyErr_SetString(PyExc_ValueError, "missing required argument");
-    return NULL;
+    return nullptr;
   }
 
-  const char *key_to_find = PyString_AsString(arg);
+  const char *key_to_find = PyUnicode_AsUTF8(arg);
   bool found = false;
 
   if (key_to_find)
@@ -259,14 +247,20 @@ static PyObject *dict_has_key(PyGRTDictObject *self, PyObject *arg) {
   return PyBool_FromLong(found);
 }
 
-static PyObject *dict_update(PyGRTDictObject *self, PyObject *arg) {
+static PyObject *dict_update(PyGRTDictObject *self, PyObject *args) {
   PythonContext *ctx = PythonContext::get_and_check();
   if (!ctx)
-    return NULL;
+    return nullptr;
 
+  if (!PyTuple_Check(args)){
+    PyErr_SetString(PyExc_ValueError, "tuple argument required for update()");
+    return nullptr;
+  }
+
+  PyObject* arg = PyTuple_GetItem(args, 0);
   if (!arg) {
     PyErr_SetString(PyExc_ValueError, "dict argument required for update()");
-    return NULL;
+    return nullptr;
   }
 
   TypeSpec type;
@@ -277,14 +271,14 @@ static PyObject *dict_update(PyGRTDictObject *self, PyObject *arg) {
     value = grt::DictRef::cast_from(ctx->from_pyobject(arg, type));
   } catch (std::exception &exc) {
     PythonContext::set_python_error(exc, "invalid argument");
-    return NULL;
+    return nullptr;
   }
 
   if (value.is_valid()) {
     merge_contents(*self->dict, value, true);
   } else {
     PyErr_SetString(PyExc_ValueError, "invalid argument for update()");
-    return NULL;
+    return nullptr;
   }
 
   Py_RETURN_NONE;
@@ -293,19 +287,19 @@ static PyObject *dict_update(PyGRTDictObject *self, PyObject *arg) {
 static PyObject *dict_get(PyGRTDictObject *self, PyObject *arg) {
   PythonContext *ctx = PythonContext::get_and_check();
   if (!ctx)
-    return NULL;
-  PyObject *def = NULL;
+    return nullptr;
+  PyObject *def = nullptr;
   char *key;
 
   if (!PyArg_ParseTuple(arg, "s|O", &key, &def))
-    return NULL;
+    return nullptr;
 
   if (key) {
     if (self->dict->has_key(key))
       return ctx->from_grt(self->dict->get(key));
     else {
       if (def) {
-        Py_INCREF(def);
+        Py_XINCREF(def);
         return def;
       } else {
         PyErr_SetString(PyExc_KeyError, base::strfmt("invalid key '%s'", key).c_str());
@@ -319,19 +313,19 @@ static PyObject *dict_get(PyGRTDictObject *self, PyObject *arg) {
 static PyObject *dict_setdefault(PyGRTDictObject *self, PyObject *arg) {
   PythonContext *ctx = PythonContext::get_and_check();
   if (!ctx)
-    return NULL;
+    return nullptr;
   PyObject *def = Py_None;
   char *key;
 
   if (!PyArg_ParseTuple(arg, "s|O", &key, &def))
-    return NULL;
+    return nullptr;
 
   if (key) {
     if (self->dict->has_key(key))
       return ctx->from_grt(self->dict->get(key));
     else {
       if (def != Py_None)
-        Py_INCREF(def);
+        Py_XINCREF(def);
       try {
         self->dict->set(key, ctx->from_pyobject(def));
       } catch (grt::bad_item &exc) {
@@ -345,8 +339,24 @@ static PyObject *dict_setdefault(PyGRTDictObject *self, PyObject *arg) {
   Py_RETURN_NONE;
 }
 
+static PyObject *dict_dir(PyGRTDictObject *self, PyObject *) {
+  static constexpr const char *const methods[] = {"keys", "items", "values", "has_key", "update", "get", "setdefault"};
+  PyObject *members = PyList_New(self->dict->count() + sizeof(methods));
+
+  int i = 0;
+  for (const auto &m : *self->dict) {
+    PyList_SET_ITEM(members, i++, PyUnicode_FromString(m.first.c_str()));
+  }
+
+  for (const auto &m : methods) {
+    PyList_SET_ITEM(members, i++, PyUnicode_FromString(m));
+  }
+
+  return members;
+}
+
 static PyObject *dict_printable(PyGRTDictObject *self) {
-  return PyString_FromString(self->dict->toString().c_str());
+  return PyUnicode_FromString(self->dict->toString().c_str());
 }
 
 static PyObject *dict_get_contenttype(PyGRTDictObject *self, void *closure) {
@@ -364,18 +374,19 @@ PyDoc_STRVAR(PyGRTDictDoc,
 
 static PyMethodDef PyGRTDictMethods[] = {
   //{"__getitem__", (PyCFunction)dict_subscript, METH_O|METH_COEXIST, getitem_doc},
-  {"keys", (PyCFunction)dict_keys, 0, NULL},
-  {"items", (PyCFunction)dict_items, 0, NULL},
-  {"values", (PyCFunction)dict_values, 0, NULL},
-  {"has_key", (PyCFunction)dict_has_key, 0, NULL},
-  {"update", (PyCFunction)dict_update, 0, NULL},
-  {"get", (PyCFunction)dict_get, METH_VARARGS, NULL},
-  {"setdefault", (PyCFunction)dict_setdefault, 0, NULL},
-  {NULL, NULL, 0, NULL}};
+  {"keys", (PyCFunction)dict_keys, METH_NOARGS, nullptr},
+  {"items", (PyCFunction)dict_items, METH_NOARGS, nullptr},
+  {"values", (PyCFunction)dict_values, METH_NOARGS, nullptr},
+  {"has_key", (PyCFunction)dict_has_key, METH_NOARGS, nullptr},
+  {"update", (PyCFunction)dict_update, METH_VARARGS, nullptr},
+  {"get", (PyCFunction)dict_get, METH_VARARGS, nullptr},
+  {"setdefault", (PyCFunction)dict_setdefault, METH_VARARGS, nullptr},
+  {"__dir__", (PyCFunction)dict_dir, METH_NOARGS, nullptr},
+  {nullptr, nullptr, 0, nullptr}};
 
-static PyGetSetDef PyGRTDictGetSetters[] = {{(char *)"contenttype", (getter)dict_get_contenttype, NULL,
-                                             (char *)"(content type, content object class|None)", NULL},
-                                            {NULL, 0, NULL, NULL, NULL}};
+static PyGetSetDef PyGRTDictGetSetters[] = {{(char *)"contenttype", (getter)dict_get_contenttype, nullptr,
+                                             (char *)"(content type, content object class|None)", nullptr},
+                                            {nullptr, 0, nullptr, nullptr, nullptr}};
 
 static PyMappingMethods PyGRTDictObject_as_mapping = {
   (lenfunc)dict_length,             // inquiry mp_length;
@@ -383,95 +394,248 @@ static PyMappingMethods PyGRTDictObject_as_mapping = {
   (objobjargproc)dict_ass_subscript // objobjargproc mp_ass_subscript;
 };
 
-static PyTypeObject PyGRTDictObjectType = {
-  PyObject_HEAD_INIT(&PyType_Type) // PyObject_VAR_HEAD
-  0,
-  "grt.Dict",                 // char *tp_name; /* For printing, in format "<module>.<name>" */
-  sizeof(PyGRTDictObject), 0, // int tp_basicsize, tp_itemsize; /* For allocation */
+static PyObject *dict_iter(PyGRTDictObject *self);
 
+
+static PyTypeObject PyGRTDictObjectType = {
+  PyVarObject_HEAD_INIT(&PyType_Type, 0) // PyObject_VAR_HEAD
+  "grt.Dict",   //  tp_name
+  sizeof(PyGRTDictObject),  //  tp_basicsize
+  0, /* tp_itemsize For allocation */
+  
   /* Methods to implement standard operations */
 
-  (destructor)dict_dealloc, //  destructor tp_dealloc;
-  0,                        //  printfunc tp_print;
-  0,                        //  getattrfunc tp_getattr;
-  0,                        //  setattrfunc tp_setattr;
-  0,                        //(cmpfunc)dict_compare, //  cmpfunc tp_compare;
-  0,                        //(reprfunc)dict_repr,//  reprfunc tp_repr;
+  (destructor)dict_dealloc, //  tp_dealloc destructor tp_dealloc;
+  0,  //  tp_print
+  0,  //  tp_getattr
+  0,  //  tp_setattr
+  0,  //  tp_as_async
+  0,  //  tp_repr
 
   /* Method suites for standard classes */
 
-  0,                           //  PyNumberMethods *tp_as_number;
-  0,                           //  PySequenceMethods *tp_as_sequence;
-  &PyGRTDictObject_as_mapping, //  PyMappingMethods *tp_as_mapping;
+  0,  //  tp_as_number
+  0,  //  tp_as_sequence
+  &PyGRTDictObject_as_mapping,    //  tp_as_mapping
 
   /* More standard operations (here for binary compatibility) */
 
-  0,                           //  hashfunc tp_hash;
-  0,                           //  ternaryfunc tp_call;
-  (reprfunc)dict_printable,    //  reprfunc tp_str;
-  (getattrofunc)dict_getattro, //  getattrofunc tp_getattro;
-  0,                           //  setattrofunc tp_setattro;
+  0,  //  tp_hash
+  0,  //  tp_call
+  (reprfunc)dict_printable,   //  tp_str
+
+  (getattrofunc)dict_getattro,  //  tp_getattro
+  0,  //  tp_setattro
 
   /* Functions to access object as input/output buffer */
-  0, //  PyBufferProcs *tp_as_buffer;
+  0,  //  tp_as_buffer
 
   /* Flags to define presence of optional/expanded features */
-  Py_TPFLAGS_DEFAULT, //  long tp_flags;
+  Py_TPFLAGS_DEFAULT, //  tp_flags
 
-  PyGRTDictDoc, //  char *tp_doc; /* Documentation string */
+  PyGRTDictDoc, /* tp_doc Documentation string */
 
   /* Assigned meaning in release 2.0 */
   /* call function for all accessible objects */
-  0, //  traverseproc tp_traverse;
+  0,  //  tp_traverse
 
   /* delete references to contained objects */
-  0, //  inquiry tp_clear;
+  0,  //  tp_clear
 
   /* Assigned meaning in release 2.1 */
   /* rich comparisons */
-  0, //  richcmpfunc tp_richcompare;
+  0,  //  tp_richcompare
 
   /* weak reference enabler */
-  0, //  long tp_weakdictoffset;
+  0,  //  tp_weaklistoffset
 
-  /* Added in release 2.2 */
   /* Iterators */
-  0, //  getiterfunc tp_iter;
-  0, //  iternextfunc tp_iternext;
+  (getiterfunc)dict_iter,    //  tp_iter
+  0,    //  tp_iternext
 
   /* Attribute descriptor and subclassing stuff */
-  PyGRTDictMethods,    //  struct PyMethodDef *tp_methods;
-  0,                   //  struct PyMemberDef *tp_members;
-  PyGRTDictGetSetters, //  struct PyGetSetDef *tp_getset;
-  0,                   //  struct _typeobject *tp_base;
-  0,                   //  PyObject *tp_dict;
-  0,                   //  descrgetfunc tp_descr_get;
-  0,                   //  descrsetfunc tp_descr_set;
-  0,                   //  long tp_dictoffset;
-  (initproc)dict_init, //  initproc tp_init;
-  PyType_GenericAlloc, //  allocfunc tp_alloc;
-  PyType_GenericNew,   //  newfunc tp_new;
-  0,                   //  freefunc tp_free; /* Low-level free-memory routine */
-  0,                   //  inquiry tp_is_gc; /* For PyObject_IS_GC */
-  0,                   //  PyObject *tp_bases;
-  0,                   //  PyObject *tp_mro; /* method resolution order */
-  0,                   //  PyObject *tp_cache;
-  0,                   //  PyObject *tp_subclasses;
-  0,                   //  PyObject *tp_weakdict;
-  0,                   // tp_del
-#if (PY_MAJOR_VERSION == 2) && (PY_MINOR_VERSION > 5)
-  0 // tp_version_tag
+  PyGRTDictMethods, //  tp_methods
+  0,  //  tp_members
+  PyGRTDictGetSetters,  //  tp_getset
+  0,  //  tp_base
+  0,  //  tp_dict
+  0,  //  tp_descr_get
+  0,  //  tp_descr_set
+  0,  //  tp_dictoffset
+  (initproc)dict_init,  //  tp_init
+  PyType_GenericAlloc,  //  tp_alloc
+  PyType_GenericNew,    //  tp_new
+  0, /* tp_free Low-level free-memory routine */
+  0, /* tp_is_gc For PyObject_IS_GC */
+  0,  //  tp_bases
+  0, /* tp_mro method resolution order */
+  0,  //  tp_cache
+  0,  //  tp_subclasses
+  0,  //  tp_weaklist
+  0,  //  tp_del
+
+  /* Type attribute cache version tag. Added in version 2.6 */
+  0,  //  tp_version_tag
+
+  0, //  tp_finalize
+#if PY_VERSION_HEX >= 0x03090000
+  nullptr   //  tp_vectorcall
+#elif PY_VERSION_HEX >= 0x03080000
+  nullptr,  //  tp_vectorcall
+  nullptr   //  tp_print
 #endif
 };
 
+typedef struct {
+  PyObject_HEAD
+  bool isNew;
+  grt::DictRef::const_iterator iterator;
+  grt::DictRef::const_iterator last; 
+  grt::DictRef::const_iterator end; 
+} PyGRTDictIteratorObject;
+
+static PyObject *dictiter_iter(PyGRTDictIteratorObject *self);
+static PyObject *dictiter_iternext(PyGRTDictIteratorObject *self);
+
+
+static PyTypeObject PyGRTDictIteratorObjectType = {
+  PyVarObject_HEAD_INIT(&PyType_Type, 0) // PyObject_VAR_HEAD
+  "grt.DictIterator",   //  tp_name
+  sizeof(PyGRTDictIteratorObject),  //  tp_basicsize
+  0, /* tp_itemsize For allocation */
+  
+  /* Methods to implement standard operations */
+
+  (destructor)dict_dealloc, //  tp_dealloc destructor tp_dealloc;
+  0,  //  tp_print
+  0,  //  tp_getattr
+  0,  //  tp_setattr
+  0,  //  tp_as_async
+  0,  //  tp_repr
+
+  /* Method suites for standard classes */
+
+  0,  //  tp_as_number
+  0,  //  tp_as_sequence
+  &PyGRTDictObject_as_mapping,    //  tp_as_mapping
+
+  /* More standard operations (here for binary compatibility) */
+
+  0,  //  tp_hash
+  0,  //  tp_call
+  (reprfunc)dict_printable,   //  tp_str
+
+  (getattrofunc)dict_getattro,  //  tp_getattro
+  0,  //  tp_setattro
+
+  /* Functions to access object as input/output buffer */
+  0,  //  tp_as_buffer
+
+  /* Flags to define presence of optional/expanded features */
+  Py_TPFLAGS_DEFAULT, //  tp_flags
+
+  "GRT Dictionary iterator object", /* tp_doc Documentation string */
+
+  /* Assigned meaning in release 2.0 */
+  /* call function for all accessible objects */
+  0,  //  tp_traverse
+
+  /* delete references to contained objects */
+  0,  //  tp_clear
+
+  /* Assigned meaning in release 2.1 */
+  /* rich comparisons */
+  0,  //  tp_richcompare
+
+  /* weak reference enabler */
+  0,  //  tp_weaklistoffset
+
+  /* Iterators */
+  (getiterfunc)dictiter_iter,    //  tp_iter
+  (iternextfunc)dictiter_iternext,    //  tp_iternext
+
+  /* Attribute descriptor and subclassing stuff */
+  0, //  tp_methods
+  0,  //  tp_members
+  0,  //  tp_getset
+  0,  //  tp_base
+  0,  //  tp_dict
+  0,  //  tp_descr_get
+  0,  //  tp_descr_set
+  0,  //  tp_dictoffset
+  0,  //  tp_init
+  0,  //  tp_alloc
+  0,    //  tp_new
+  0, /* tp_free Low-level free-memory routine */
+  0, /* tp_is_gc For PyObject_IS_GC */
+  0,  //  tp_bases
+  0, /* tp_mro method resolution order */
+  0,  //  tp_cache
+  0,  //  tp_subclasses
+  0,  //  tp_weaklist
+  0,  //  tp_del
+
+  /* Type attribute cache version tag. Added in version 2.6 */
+  0,  //  tp_version_tag
+
+  0, //  tp_finalize
+#if PY_VERSION_HEX >= 0x03090000
+  nullptr   //  tp_vectorcall
+#elif PY_VERSION_HEX >= 0x03080000
+  nullptr,  //  tp_vectorcall
+  nullptr   //  tp_print
+#endif
+};
+
+
+static PyObject *dict_iter(PyGRTDictObject *self) {
+  PyGRTDictIteratorObject *object = (PyGRTDictIteratorObject *)PyType_GenericNew(&PyGRTDictIteratorObjectType, nullptr, nullptr);
+  
+  object->isNew = true;
+  object->iterator = self->dict->begin();
+  object->last = --self->dict->end();
+  object->end = self->dict->end();
+  
+  return (PyObject *)object;
+}
+
+static PyObject *dictiter_iter(PyGRTDictIteratorObject *self) {
+  Py_XINCREF(self);
+  self->isNew = true;
+  return (PyObject *) self;
+}
+
+static PyObject *dictiter_iternext(PyGRTDictIteratorObject *self) {
+  if (self->iterator == self->last || self->iterator == self->end) {
+    PyErr_SetNone(PyExc_StopIteration);
+    return nullptr;
+  }
+  
+  if(!self->isNew) {
+    ++self->iterator;
+  }
+  
+  self->isNew = false;  
+  
+  PythonContext *ctx = PythonContext::get_and_check();
+  return ctx->from_grt(self->iterator->second);
+  
+}
+
 void grt::PythonContext::init_grt_dict_type() {
-  PyGRTDictObjectType.tp_new = PyType_GenericNew;
   if (PyType_Ready(&PyGRTDictObjectType) < 0) {
+    PyErr_Print();
     throw std::runtime_error("Could not initialize GRT Dict type in python");
   }
 
-  Py_INCREF(&PyGRTDictObjectType);
-  PyModule_AddObject(get_grt_module(), "Dict", (PyObject *)&PyGRTDictObjectType);
+  if (PyType_Ready(&PyGRTDictIteratorObjectType) < 0) {
+    PyErr_Print();
+    throw std::runtime_error("Could not initialize GRT Dict type in python");
+  }
+
+  Py_XINCREF(&PyGRTDictObjectType);
+  Py_XINCREF(&PyGRTDictIteratorObjectType);
+  PyModule_AddObject(get_grt_module(), "Dict", reinterpret_cast<PyObject *>(&PyGRTDictObjectType));
 
   _grt_dict_class = PyDict_GetItemString(PyModule_GetDict(get_grt_module()), "Dict");
 }
