@@ -1,20 +1,24 @@
 /*
- * Copyright (c) 2009, 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2018, Oracle and/or its affiliates. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; version 2 of the
- * License.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have included with MySQL.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
  */
 
 #include "base/util_functions.h"
@@ -30,7 +34,9 @@
 #include "db_mysql_sql_export.h"
 #include "base/string_utilities.h"
 #include "mforms/fs_object_selector.h"
+#include "mforms/app.h"
 #include "grts/structs.workbench.h"
+#include "grtdb/db_object_helpers.h"
 
 using namespace grtui;
 using namespace mforms;
@@ -76,6 +82,17 @@ public:
     _generate_drop_schema_check.set_text(_("Generate DROP SCHEMA"));
     _options_box.add(&_generate_drop_schema_check, false, true);
 
+    _sortTablesAlphabeticallyCheck.set_text(_("Sort Tables Alphabetically"));
+    _sortTablesAlphabeticallyCheck.set_name("Sort Tables Alphabetically");
+    auto box = mforms::manage(new Box(true));
+    box->add(&_sortTablesAlphabeticallyCheck, false, true);
+    auto img = mforms::manage(new ImageBox());
+    img->set_image(mforms::App::get()->get_resource_path("mini_notice.png"));
+    img->set_tooltip("When this is unchecked, tables will be sorted according to foreign key references.");
+    box->add(img, false, true);
+
+    _options_box.add(box, false, true);
+
     _skip_foreign_keys_check.set_text(_("Skip Creation of FOREIGN KEYS"));
     _options_box.add(&_skip_foreign_keys_check, false, true);
     scoped_connect(_skip_foreign_keys_check.signal_clicked(), std::bind(&ExportInputPage::SkipFKToggled, this));
@@ -108,6 +125,7 @@ public:
 
     _generate_drop_check.set_active(form->module()->document_int_data("generate_drop", false) != 0);
     _generate_drop_schema_check.set_active(form->module()->document_int_data("generate_schema_drop", 0) != 0);
+    _sortTablesAlphabeticallyCheck.set_active(form->module()->document_int_data("SortTablesAlphabetically", 0) != 0);
     _skip_foreign_keys_check.set_active(form->module()->document_int_data("skip_foreign_keys", false) != 0);
     _skip_FK_indexes_check.set_active(form->module()->document_int_data("SkipFKIndexes", false) != 0);
     _omit_schema_qualifier_check.set_active(form->module()->document_int_data("omit_schema_qualifier", false) != 0);
@@ -154,6 +172,7 @@ public:
 
       values().gset("GenerateDrops", _generate_drop_check.get_active());
       values().gset("GenerateSchemaDrops", _generate_drop_schema_check.get_active());
+      values().gset("SortTablesAlphabetically", _sortTablesAlphabeticallyCheck.get_active());
       values().gset("SkipForeignKeys", _skip_foreign_keys_check.get_active());
       values().gset("SkipFKIndexes", _skip_FK_indexes_check.get_active());
       values().gset("GenerateWarnings", _generate_show_warnings_check.get_active());
@@ -171,6 +190,7 @@ public:
       module->set_document_data("create_sql_output_filename", _file_selector->get_filename());
       module->set_document_data("generate_drop", _generate_drop_check.get_active());
       module->set_document_data("generate_schema_drop", _generate_drop_schema_check.get_active());
+      module->set_document_data("SortTablesAlphabetically", _sortTablesAlphabeticallyCheck.get_active());
       module->set_document_data("skip_foreign_keys", _skip_foreign_keys_check.get_active());
       module->set_document_data("SkipFKIndexes", _skip_FK_indexes_check.get_active());
       module->set_document_data("omit_schema_qualifier", _omit_schema_qualifier_check.get_active());
@@ -209,6 +229,7 @@ protected:
   CheckBox _no_FK_for_inserts;
   CheckBox _triggers_after_inserts;
   CheckBox _omit_schema_qualifier_check;
+  CheckBox _sortTablesAlphabeticallyCheck;
 };
 
 //--------------------------------------------------------------------------------
@@ -301,6 +322,7 @@ protected:
     _export_be->set_option("TriggersAfterInserts", values().get_int("TriggersAfterInserts") != 0);
     _export_be->set_option("OmitSchemata", values().get_int("OmitSchemata") != 0);
     _export_be->set_option("GenerateUse", values().get_int("GenerateUse") != 0);
+    _export_be->set_option("SortTablesAlphabetically", values().get_int("SortTablesAlphabetically") != 0);
 
     _export_be->set_option("TablesAreSelected", _table_filter->get_active());
     _export_be->set_option("TriggersAreSelected", _trigger_filter->get_active());
@@ -311,7 +333,9 @@ protected:
     _export_be->set_option("OutputScriptHeader", header);
 
     // take target version from the version in the model
-    _export_be->set_db_options_for_version(_export_be->get_catalog()->version());
+
+    _export_be->set_db_options_for_version(
+        GrtVersionRef::cast_from(bec::getModelOption(workbench_physical_ModelRef::cast_from(_export_be->get_catalog()->owner()), "CatalogVersion")));
 
     return true;
   }
@@ -394,7 +418,7 @@ class WbPluginSQLExport : public WizardPlugin {
 
 public:
   WbPluginSQLExport(grt::Module *module) : WizardPlugin(module) {
-    set_name("sql_export_wizard");
+    set_name("SQL Export Wizard");
     add_page(mforms::manage(new ExportInputPage(this)));
     add_page(mforms::manage(new ExportFilterPage(this, &_export_be)));
     add_page(mforms::manage(new PreviewScriptPage(this, &_export_be)));
