@@ -1,19 +1,23 @@
-# Copyright (c) 2012, 2014, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
 #
-# This program is free software; you can redistribute it and/or
-# modify it under the terms of the GNU General Public License as
-# published by the Free Software Foundation; version 2 of the
-# License.
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License, version 2.0,
+# as published by the Free Software Foundation.
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU General Public License for more details.
+# This program is also distributed with certain software (including
+# but not limited to OpenSSL) that is licensed under separate terms, as
+# designated in a particular file or component or in included license
+# documentation.  The authors of MySQL hereby grant you an additional
+# permission to link the program and your derivative works with the
+# separately licensed software that they have included with MySQL.
+# This program is distributed in the hope that it will be useful,  but
+# WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+# the GNU General Public License, version 2.0, for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-# 02110-1301  USA
+# along with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 
 import mforms
 import grt
@@ -49,13 +53,13 @@ class ReplaceForm(mforms.Form):
         content.set_spacing(12)
 
         v_box = mforms.newBox(False)
-        content.add(v_box, False, False)
+        content.add(v_box, False, True)
         v_box.set_spacing(12)
-        v_box.add(mforms.newLabel(description), False, False)
+        v_box.add(mforms.newLabel(description), False, True)
 
         table = mforms.newTable()
         table.set_padding(12)
-        v_box.add(table, False, False)
+        v_box.add(table, False, True)
         table.set_row_count(2)
         table.set_column_count(2)
         table.set_row_spacing(8)
@@ -70,7 +74,7 @@ class ReplaceForm(mforms.Form):
         table.add(self.to_type_entry, 1, 2, 1, 2)
 
         h_box = mforms.newBox(True)
-        content.add_end(h_box, False, False)
+        content.add_end(h_box, False, True)
         h_box.set_spacing(12)
 
         self.cancel_btn = mforms.newButton()
@@ -100,25 +104,31 @@ class MainView(WizardPage):
 
     def create_ui(self):
         self.content.set_spacing(4)
-        self.content.add(mforms.newLabel("Review and edit migrated objects. You can manually edit the generated SQL before applying them to the target database."), False, True)
+        description = mforms.newLabel("Review and edit migrated objects. You can manually edit the generated SQL before applying them to the target database.")
+        description.set_name('Page Description')
+        self.content.add(description, False, True)
         
         hbox = mforms.newBox(True)
         self.tree_head_label = mforms.newLabel("Migrated Objects")
-        hbox.add(self.tree_head_label, False, False)
+        self.tree_head_label.set_name('Header')
+        hbox.add(self.tree_head_label, False, True)
         self._filter = mforms.newSelector()
+        self._filter.set_name('Change View')
         self._filter.add_items(["Migration Problems", "All Objects", "Column Mappings"])
         self._filter.add_changed_callback(self._filter_changed)
         hbox.add_end(self._filter, False, True)
-        hbox.add_end(mforms.newLabel("View:"), False, False)
+        hbox.add_end(mforms.newLabel("View:"), False, True)
         self.content.add(hbox, False, True)
         
         self._no_errors_text = "No migration problems found. %d warning(s).\nUse the View pulldown menu to review all objects."
         self._no_errors = mforms.newLabel('')  # Label text will be set later when the warning count is calculated
+        self._no_errors.set_name('Problems Found')
         self._no_errors.set_style(mforms.BigStyle)
         self._no_errors.set_text_align(mforms.MiddleLeft)
         self.content.add(self._no_errors, True, True)
         
-        self._tree = mforms.newTreeNodeView(mforms.TreeDefault)
+        self._tree = mforms.newTreeView(mforms.TreeDefault)
+        self._tree.set_name('All Objects')
         self._tree.add_column(mforms.IconStringColumnType, "Source Object", 200, False)
         self._tree.add_column(mforms.IconStringColumnType, "Target Object", 200, True)
         self._tree.add_column(mforms.IconStringColumnType, "Migration Message", 300, False)
@@ -129,12 +139,13 @@ class MainView(WizardPage):
 
         self._all_menu = mforms.newContextMenu()
         self._all_menu.add_will_show_callback(self.all_menu_will_show)
-        self._all_menu.add_check_item_with_title("Skip Object", self.skip_object, "skip_object")
+        self._all_menu.add_check_item_with_title("Skip Object", self.skip_object, "Skip Object", "skip_object")
 
         self._tree.set_context_menu(self._all_menu)
 
         
-        self._columns = mforms.newTreeNodeView(mforms.TreeShowColumnLines|mforms.TreeShowRowLines|mforms.TreeFlatList)
+        self._columns = mforms.newTreeView(mforms.TreeShowColumnLines|mforms.TreeShowRowLines|mforms.TreeFlatList)
+        self._columns.set_name('Column Mappings')
         self.COL_SOURCE_SCHEMA = self._columns.add_column(mforms.StringColumnType, "Source Schema", 100, False)
         self.COL_SOURCE_TABLE = self._columns.add_column(mforms.IconStringColumnType, "Source Table", 100, False)
         self.COL_SOURCE_COLUMN = self._columns.add_column(mforms.IconStringColumnType, "Source Column", 100, False)
@@ -163,19 +174,21 @@ class MainView(WizardPage):
         
         self._menu = mforms.newContextMenu()
         self._menu.add_will_show_callback(self.menu_will_show)
-        self._menu.add_item_with_title("Set Target Type of Selected Columns...", self.set_target_type, "set_target_type")
-        self._menu.add_item_with_title("Find and Replace Target Type...", self.replace_target_type, "replace_target_type")
-        self._menu.add_item_with_title("Find and Replace Target Flags...", self.replace_target_flags, "replace_target_flags")
-        self._menu.add_item_with_title("Find and Replace Target Default Value...", self.replace_target_default_value, "replace_target_default_value")
-        self._menu.add_item_with_title("Find and Replace Target Collation...", self.replace_target_collation, "replace_target_collation")
+        self._menu.add_item_with_title("Set Target Type of Selected Columns...", self.set_target_type, "Set Target Type", "set_target_type")
+        self._menu.add_item_with_title("Find and Replace Target Type...", self.replace_target_type, "Replace Target Type", "replace_target_type")
+        self._menu.add_item_with_title("Find and Replace Target Flags...", self.replace_target_flags, "Replace Target Flags", "replace_target_flags")
+        self._menu.add_item_with_title("Find and Replace Target Default Value...", self.replace_target_default_value, "Replace Target Default Value", "replace_target_default_value")
+        self._menu.add_item_with_title("Find and Replace Target Collation...", self.replace_target_collation, "Replace Target Collation", "replace_target_collation")
         self._columns.set_context_menu(self._menu)
         
-        self.help_label = mforms.newLabel("You can rename target schemas and tables and change column definitions by clicking them once selected.")
+        self.help_label = mforms.newLabel("You can rename target schemas and tables, and change column definitions by clicking them once selected.")
+        self.help_label.set_name('Help Message')
         self.help_label.set_style(mforms.SmallStyle)
         self.content.add(self.help_label, False, True)
         
         self._advbox = mforms.newPanel(mforms.TitledBoxPanel)
         self._advbox.set_title("SQL CREATE Script for Selected Object")
+        self._advbox.set_name('SQL Editor')
         box = mforms.newBox(True)
         self._code = mforms.newCodeEditor()
         self._code.set_language(mforms.LanguageMySQL)
@@ -187,12 +200,14 @@ class MainView(WizardPage):
 
         self._lock_check = mforms.newCheckBox()
         self._lock_check.set_text("Lock edited SQL")
+        self._lock_check.set_name("Lock Edited SQL")
         self._lock_check.set_tooltip("Lock the SQL code to the edited one, preventing automatic regenerations from discarding changes made directly to the SQL script.")
         self._lock_check.add_clicked_callback(self._lock_clicked)
         vbox.add(self._lock_check, False, True)
 
         self._comment_check = mforms.newCheckBox()
         self._comment_check.set_text("Comment out")
+        self._comment_check.set_name("Comment Out")
         self._comment_check.set_tooltip("Mark the object to be commented out on the generated script, making it not get created in the target server.")
         self._comment_check.add_clicked_callback(self._comment_clicked)
         vbox.add(self._comment_check, False, True)
@@ -204,11 +219,13 @@ class MainView(WizardPage):
 
         self._revert_btn = mforms.newButton()
         self._revert_btn.set_text("Discard Changes")
+        self._revert_btn.set_name("Discard Changes")
         vbox.add_end(self._revert_btn, False, True)
         self._revert_btn.add_clicked_callback(self._discard_clicked)
 
         self._apply_btn = mforms.newButton()
         self._apply_btn.set_text("Apply Changes")
+        self._apply_btn.set_name("Apply Changes")
         vbox.add_end(self._apply_btn, False, True)
         self._apply_btn.add_clicked_callback(self._apply_clicked)
         box.add(vbox, False, True)
@@ -298,7 +315,7 @@ class MainView(WizardPage):
                         try:
                             if not object.setParseType(type, None):
                                 raise Exception("Could not parse column type string '%s'" % type)
-                        except Exception, exc:
+                        except Exception as exc:
                             mforms.Utilities.show_error("Change Column Type", "Error changing column type: %s" % exc, "OK", "", "")
                             return
                         node.set_string(1, name+"  "+object.formattedRawType)
@@ -316,7 +333,7 @@ class MainView(WizardPage):
         object = self._object_dict.get(node.get_tag(), None)
         if object and isinstance(object, grt.classes.db_Column):
             if object.owner.customData.get("migration:lock_temp_sql", False):
-                if mforms.Utilities.show_message("Object is Locked", "The object was manually edited and is locked against updates. Would you like to unlock the object discarding your edits to apply this change?",
+                if mforms.Utilities.show_message("Object is Locked", "The object was manually edited and is locked against updates. Would you like to unlock the object discard your edits to apply this change?",
                                           "Unlock Object", "Cancel", "") == mforms.ResultCancel:
                     return
                 grt.log_info("Migration", "User unlocked object '%s' by changing columns tree" % object.name)
@@ -331,7 +348,7 @@ class MainView(WizardPage):
                 try:
                     if not object.setParseType(value, None):
                         raise Exception("Could not parse column type string '%s'" % value)
-                except Exception, exc:
+                except Exception as exc:
                     mforms.Utilities.show_error("Change Column Type", "Error changing column type: %s" % exc, "OK", "", "")
                     return
                 node.set_string(column, value)                
@@ -344,13 +361,13 @@ class MainView(WizardPage):
                 grt.log_info("Migration", "User changed target column flags of '%s' to '%s'\n"%(object.name, value))
                 self._regenerateSQL()
             elif column == self.COL_TARGET_AI:
-                node.set_bool(column, int(value))
-                object.autoIncrement = int(value)
+                node.set_bool(column, int(value) != 0)
+                object.autoIncrement = (int(value) != 0)
                 grt.log_info("Migration", "User changed target column autoIncrement of '%s' to '%s'\n"%(object.name, value))
                 self._regenerateSQL()
             elif column == self.COL_TARGET_NOTNULL:
-                node.set_bool(column, int(value))
-                object.isNotNull = int(value)
+                node.set_bool(column, int(value) != 0)
+                object.isNotNull = (int(value) != 0)
                 grt.log_info("Migration", "User changed target column isNotNull of '%s' to '%s'\n"%(object.name, value))
                 self._regenerateSQL()
             elif column == self.COL_TARGET_DEFAULT:
@@ -410,8 +427,8 @@ class MainView(WizardPage):
         if object and hasattr(object, "temp_sql"):
             self._code.set_text(object.temp_sql)
             self._code.set_enabled(not object.commentedOut)
-            self._comment_check.set_active(object.commentedOut)
-            self._lock_check.set_active(object.customData.get("migration:lock_temp_sql", False))
+            self._comment_check.set_active(object.commentedOut != 0)
+            self._lock_check.set_active(bool(object.customData.get("migration:lock_temp_sql", False)))
             self._advbox.set_enabled(True)
             self._apply_btn.set_enabled(False)
             self._revert_btn.set_enabled(False)
@@ -474,7 +491,7 @@ class MainView(WizardPage):
                     if tschema.oldName == schema.name:
                         if tschema.name == schema.name:
                             mforms.Utilities.show_error("Validation Error", 
-                                "The source and target are in the same server and a schema being migrated have identical names.\nPlease rename the target schema to allow the migration to continue.",
+                                "The source and target are in the same server and a schema being migrated has identical names.\nPlease rename the target schema to allow the migration to continue.",
                                 "OK", "", "")
                             idx = self._filter.index_of_item_with_title('All Objects')
                             if idx == -1:
@@ -719,7 +736,7 @@ class MainView(WizardPage):
                     node.set_string(self.COL_SOURCE_COLUMN, scolumn.name)
                     node.set_string(self.COL_SOURCE_TYPE, scolumn.formattedRawType)
                     node.set_string(self.COL_SOURCE_FLAGS, " ".join(scolumn.flags))
-                    node.set_bool(self.COL_SOURCE_NOTNULL, scolumn.isNotNull)            
+                    node.set_bool(self.COL_SOURCE_NOTNULL, scolumn.isNotNull != 0)
                     node.set_string(self.COL_SOURCE_DEFAULT, scolumn.defaultValue)
                     node.set_string(self.COL_SOURCE_COLLATION, scolumn.collationName)
 
@@ -738,8 +755,8 @@ class MainView(WizardPage):
                         node.set_string(self.COL_TARGET_COLUMN, tcolumn.name)
                         node.set_string(self.COL_TARGET_TYPE, tcolumn.formattedRawType)
                         node.set_string(self.COL_TARGET_FLAGS, " ".join(tcolumn.flags))
-                        node.set_bool(self.COL_TARGET_AI, tcolumn.autoIncrement)
-                        node.set_bool(self.COL_TARGET_NOTNULL, tcolumn.isNotNull)
+                        node.set_bool(self.COL_TARGET_AI, tcolumn.autoIncrement != 0)
+                        node.set_bool(self.COL_TARGET_NOTNULL, tcolumn.isNotNull != 0)
                         node.set_string(self.COL_TARGET_DEFAULT, tcolumn.defaultValue)
                         node.set_string(self.COL_TARGET_COLLATION, tcolumn.collationName)
                         self._set_log_entry_for(node, scolumn, tcolumn, self.COL_MESSAGE)
@@ -857,7 +874,7 @@ class MainView(WizardPage):
         if tag and tag in self._object_dict:
             obj = self._object_dict[tag]
             if hasattr(obj, 'commentedOut'):
-                self._all_menu.get_item(0).set_checked(obj.commentedOut)
+                self._all_menu.get_item(0).set_checked(obj.commentedOut != 0)
                 if obj.__grtclassname__ in ("db.Index", "db.ForeignKey"):
                     self._all_menu.get_item(0).set_enabled(True)
 
@@ -877,7 +894,7 @@ class MainView(WizardPage):
         if selected_node:
             to_replace = selected_node.get_string(type)
             repl_form = ReplaceForm(title, description)
-            ret, to_replace, replace_with = repl_form.show(to_replace)
+            ret, to_replace, replace_with = repl_form.show(str(to_replace))
             if ret:
                 for i in range(self._columns.count()):
                     node = self._columns.node_at_row(i)
@@ -886,7 +903,7 @@ class MainView(WizardPage):
 
     def replace_target_type(self):
         self.replace_target("Find and Replace Target Type", 
-                            "Target/migrated data type matching the search term will be replaced for all columns of all tables.", 
+                            "Target/migrated data types matching the search term will be replaced for all columns of all tables.", 
                             self.COL_TARGET_TYPE)
 
     def replace_target_flags(self):
@@ -896,10 +913,10 @@ class MainView(WizardPage):
 
     def replace_target_default_value(self):
         self.replace_target("Find and Replace Target Default Value", 
-                            "Target/migrated default value matching the search term will be replaced for all columns of all tables.", 
+                            "Target/migrated default values matching the search term will be replaced for all columns of all tables.", 
                             self.COL_TARGET_DEFAULT)
 
     def replace_target_collation(self):
         self.replace_target("Find and Replace Target Collation", 
-                            "Target/migrated collation matching the search term will be replaced for all columns of all tables.", 
+                            "Target/migrated collations matching the search term will be replaced for all columns of all tables.", 
                             self.COL_TARGET_COLLATION)
