@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2017, 2019, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
@@ -18,7 +18,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 #include "duk_module_node.h"
@@ -256,7 +256,7 @@ void ScriptingContext::runImmediates() {
 
       // Finally remove the callback object from the stash.
       duk_del_prop_string(_ctx, -1, id.c_str());
-      
+
       duk_debugger_cooperate(_ctx);
     }
   }
@@ -287,7 +287,7 @@ JSObject ScriptingContext::loadJsonFile(std::string const& fileName) {
   } catch (...) {
     checkForErrors();
   }
-  
+
   auto result = JSObject(this, -1);
   duk_pop(_ctx);
 
@@ -321,7 +321,7 @@ void ScriptingContext::checkForErrors() const {
 //----------------------------------------------------------------------------------------------------------------------
 
 /**
- * Creates an error in the scripting enironment (which acts like a normal exception on C++ side). 
+ * Creates an error in the scripting enironment (which acts like a normal exception on C++ side).
  */
 void ScriptingContext::throwScriptingError(ScriptingError error, std::string const& message) const {
   duk_push_error_object_raw(_ctx, static_cast<duk_int_t>(error), nullptr, 0, "%s", message.c_str());
@@ -382,7 +382,7 @@ void ScriptingContext::defineClass(JSObject &target, std::string const& name, st
   duk_push_c_function(_ctx, ScriptingContext::constructor, argCount);
   duk_push_string(_ctx, "name");
   duk_push_string(_ctx, name.c_str());
-  duk_def_prop(_ctx, -3, DUK_DEFPROP_HAVE_VALUE | DUK_READ_ONLY); // Cannot be changed.
+  duk_def_prop(_ctx, -3, DUK_DEFPROP_HAVE_VALUE | DUK_READ_ONLY | DUK_DEFPROP_SET_ENUMERABLE); // Cannot be changed.
 
   // Stash the new class, so we can find it later (for inheritance or manual instantiation).
   // We can do this as we use this method only for internal class references (otherwise we would need to "require()"
@@ -810,7 +810,7 @@ void ScriptingContext::emitEvent(EventEmitter const* emitter) const {
       // stack: [ event-name <varargs> array listener-object listener this-binding <varargs> ]
       duk_int_t result = duk_pcall_method(_ctx, argCount);
       if (result != DUK_EXEC_SUCCESS) {
-        throwScriptingError(ScriptingError::Error, Utils::format("callback failed, %s", duk_safe_to_string(_ctx, -1)));
+        throwScriptingError(ScriptingError::Error, Utilities::format("callback failed, %s", duk_safe_to_string(_ctx, -1)));
       } else if (once) {
         removalCandidates.insert(index);
       }
@@ -965,7 +965,7 @@ void ScriptingContext::removeEventListener(EventEmitter const* emitter) const {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-std::string ScriptingContext::logOutput(const char *errorName) const {
+std::string ScriptingContext::logOutput(const char *errorName) {
   // stack: [ message? <varargs> ]
   format();
 
@@ -973,7 +973,7 @@ std::string ScriptingContext::logOutput(const char *errorName) const {
     duk_push_error_object(_ctx, DUK_ERR_ERROR, "%s", duk_require_string(_ctx, -1));
     duk_push_string(_ctx, "name");
     duk_push_string(_ctx, errorName);
-    duk_def_prop(_ctx, -3, DUK_DEFPROP_FORCE | DUK_DEFPROP_HAVE_VALUE);
+    duk_def_prop(_ctx, -3, DUK_DEFPROP_FORCE | DUK_DEFPROP_HAVE_VALUE | DUK_DEFPROP_SET_ENUMERABLE);
     duk_get_prop_string(_ctx, -1, "stack");
     getCleanedStackTrace();
   }
@@ -994,7 +994,7 @@ std::string ScriptingContext::logOutput(const char *errorName) const {
  *
  * Expects all parameters on the stack and returns the formatted string as new TOS.
  */
-void ScriptingContext::format() const {
+void ScriptingContext::format() {
 
   // Stack can vary here. There can be no format string or the format string doesn't contain (enough) format specifiers
   // for all parameters. In that case they are simply stringified and appended to the result string.
@@ -1006,13 +1006,18 @@ void ScriptingContext::format() const {
   }
 
   std::string result;
-
   if (top == 1 || !duk_is_string(_ctx, 0)) {
-    // No format string or no additional parameters.
-    for (duk_int_t i = 0; i < top; ++i) {
-      if (!result.empty())
-        result += " ";
-      result += duk_to_string(_ctx, i);
+    if (duk_is_object(_ctx, 0)) {
+      duk_dup(_ctx, static_cast<duk_idx_t>(0));
+      result = JSValueBase(this, -1).dumpObject(false, 5);
+      duk_pop(_ctx);
+    } else {
+      // No format string or no additional parameters.
+      for (duk_int_t i = 0; i < top; ++i) {
+        if (!result.empty())
+          result += " ";
+        result += duk_to_string(_ctx, i);
+      }
     }
   } else {
     std::string format = duk_get_string(_ctx, 0);
@@ -1075,7 +1080,7 @@ void ScriptingContext::format() const {
       result += std::string(" ") + duk_to_string(_ctx, currentArgument++);
     }
   }
-  
+
   duk_push_lstring(_ctx, result.c_str(), result.size());
 }
 
@@ -1104,7 +1109,7 @@ void ScriptingContext::getCleanedStackTrace() const {
   duk_pop(_ctx); // Remove stack trace from stack.
 
   // Clean up the stack trace a bit. There's some stuff in it that isn't interesting for JS.
-  std::vector<std::string> lines = Utils::split(error);
+  std::vector<std::string> lines = Utilities::split(error);
   lines.erase(std::remove_if(lines.begin(), lines.end(), [](std::string const& line) {
     return (line.find(".cpp") != std::string::npos) || (line.find("duktape") != std::string::npos);
   }), lines.end());
@@ -1124,7 +1129,7 @@ void ScriptingContext::getCleanedStackTrace() const {
       }
     }
   }
-  error = Utils::concat(lines);
+  error = Utilities::concat(lines);
   duk_push_string(_ctx, error.c_str());
 }
 
@@ -1496,7 +1501,7 @@ std::string ScriptingContext::resolveFolder(ScriptingContext *context, std::stri
  */
 std::set<std::string> ScriptingContext::moduleFolders(std::string const& path) {
   std::set<std::string> result;
-  std::vector<std::string> parts = Utils::splitBySet(path, R"(/\)");
+  std::vector<std::string> parts = Utilities::splitBySet(path, R"(/\)");
 
   for (ssize_t i = static_cast<ssize_t>(parts.size()) - 1; i >= 0; --i) {
     if (parts[static_cast<size_t>(i)] == "node_modules")
@@ -1536,7 +1541,7 @@ duk_ret_t ScriptingContext::resolveModule(duk_context *ctx) {
   std::string cwd = Process::cwd();
 
   try {
-    if (Path::isAbsolute(requestedID) || Utils::hasPrefix(requestedID, ".")) {
+    if (Path::isAbsolute(requestedID) || Utilities::hasPrefix(requestedID, ".")) {
       std::string temp;
       if (Path::isAbsolute(requestedID)) {
         temp = Path::relative(cwd, requestedID);
@@ -1603,7 +1608,7 @@ duk_ret_t ScriptingContext::resolveModule(duk_context *ctx) {
   }
 
   if (resolvedID.empty()) {
-    context->throwScriptingError(ScriptingError::Error, Utils::format("Cannot resolve module %s", requestedID.c_str()));
+    context->throwScriptingError(ScriptingError::Error, Utilities::format("Cannot resolve module %s", requestedID.c_str()));
     return 0;
   }
 
@@ -1632,7 +1637,7 @@ duk_ret_t ScriptingContext::loadModule(duk_context *ctx) {
     return 0;
   }
 
-  std::string extension = Utils::toLower(Path::extname(requestedID));
+  std::string extension = Utilities::toLower(Path::extname(requestedID));
   duk_dup(ctx, -3);
   duk_put_prop_string(ctx, -2, "filename");
   try {
@@ -1644,7 +1649,7 @@ duk_ret_t ScriptingContext::loadModule(duk_context *ctx) {
     return 1; // Use result on stack.
   } catch (std::runtime_error &e) {
     context->throwScriptingError(ScriptingError::Uri,
-                                 Utils::format("Cannot load module %s, %s", requestedID.c_str(), e.what()));
+                                 Utilities::format("Cannot load module %s, %s", requestedID.c_str(), e.what()));
 
     return 0; // Undefined.
   }
